import request from '@/utils/request'

// 查询【请填写功能名称】列表
export function listSecret(query) {
  return request({
    url: '/system/secret/list',
    method: 'get',
    params: query
  })
}

// 查询【请填写功能名称】详细
export function getSecret(id) {
  return request({
    url: '/system/secret/' + id,
    method: 'get'
  })
}

// 新增【请填写功能名称】
export function addSecret(data) {
  return request({
    url: '/system/secret',
    method: 'post',
    data: data
  })
}

// 修改【请填写功能名称】
export function updateSecret(data) {
  return request({
    url: '/system/secret',
    method: 'put',
    data: data
  })
}

// 修改【请填写功能名称】
export function closeAuthority(data) {
  return request({
    url: '/system/secret/closeAuthority',
    method: 'put',
    data: data
  })
}

// 修改【请填写功能名称】
export function updateIsSwitch(data) {
  return request({
    url: '/system/secret/updateIsSwitch',
    method: 'put',
    data: data
  })
}

// 删除【请填写功能名称】
export function delSecret(id) {
  return request({
    url: '/system/secret/' + id,
    method: 'delete'
  })
}

// 复制【请填写功能名称】
export function copySecret(data) {
  return request({
    url: '/system/secret/copy',
    method: 'post',
    data: data
  })
}
